// 优化任务
import {
  queryMandate,
  queryMandateChildList,
  querySimulationProfit,
  queryUserList
} from '@/services/SmartOps';
import { history, useLocation, useParams, useRequest } from '@umijs/max';
import { Button, Col, Row, Table } from 'antd';
import dayjs from 'dayjs';
import { useMemo } from 'react';
import styles from './OptimizationTasks.less';
import Panel from './components/Panel';

const OptimizationTasks = (props) => {
  const { projectId } = useParams();
  const { score } = useLocation();

  const { data, run } = useRequest(queryMandate, {
    manual: true,
  });
  const { data: userList } = useRequest(queryUserList, {
    defaultParams: [{ projectId }],
  });

  const ResponsiblePeople = useMemo(() => {
    if (!data || !userList) return '-';
    let user = userList.data.find((item) => item.ID == data.ResponsiblePeople);
    return user?.CName || '-';
  }, [data, userList]);

  const status = { 0: '未处理', 2: '已完成', 4: '已忽略', 5: '已派遣' };

  return (
    <div>
      <Button
        type="primary"
        style={{ marginBottom: 20 }}
        onClick={() => history.go(-1)}
      >
        返回
      </Button>
      <Produce
        projectId={projectId}
        score={score}
        queryMandate={run}
        mandate={data}
      />
      <Cost projectId={projectId} />

      {data && (
        <div
          style={{ backgroundColor: '#a0bcda54', padding: 10, height: '100%' }}
        >
          <Row
            gutter={16}
            className={styles.detail}
            style={{ marginBottom: 0 }}
          >
            <Col span={8}>
              <div style={{ textAlign: 'center' }}>任务类型：系统发送</div>
            </Col>
            <Col span={8}>
              <div style={{ textAlign: 'center' }}>
                任务负责人：{ResponsiblePeople}
              </div>
            </Col>
            <Col span={8}>
              <div style={{ textAlign: 'center' }}>
                任务状态：{status[data?.Status]}
              </div>
            </Col>
          </Row>
        </div>
      )}
    </div>
  );
};

const Produce = ({ projectId, queryMandate }) => {
  const columns = [
    {
      title: '参数',
      dataIndex: 'Title',
    },
    {
      title: '调整内容',
      dataIndex: 'Content',
    },
  ];

  const { data } = useRequest(queryMandateChildList, {
    defaultParams: [
      {
        projectId,
        mandateClass: 1,
      },
    ],
    onSuccess(data) {
      if (data.length > 0) {
        queryMandate({
          mandate_id: data[0]?.MandateId,
        });
      }
    },
  });

  return (
    <Panel
      title="生产调度类"
      style={{ marginBottom: 20, overflow: 'hidden', position: 'relative' }}
    >
      {data?.length > 0 && (
        <>
          <div
            style={{
              background: '#12CEB3',
              width: 200,
              position: 'absolute',
              top: 30,
              right: -55,
              textAlign: 'center',
              // color: '#fff',
              fontSize: 18,
              transform: 'rotate(45deg)',
              padding: '4px 0',
            }}
          >
            任务已发送
          </div>
          <h3 className={styles.title}>任务总结</h3>
          <div className={styles.desc}>
            根据水质相关数艍．建议您调节以下参数，水厂运行可达较优状态
          </div>
          <Table columns={columns} dataSource={data} />
        </>
      )}
      {!data?.length && (
        <>
          <h3 className={styles.title}>任务总结</h3>
          <div className={styles.desc}>
            当前进水数据稳定，产水数据稳定，暂无需调节任务，继续保持哦~
          </div>
        </>
      )}
    </Panel>
  );
};

const Cost = ({ projectId }) => {
  const columns = [
    {
      title: '设备',
      dataIndex: 'Title',
    },
    {
      title: '调整内容',
      dataIndex: 'Content',
    },
  ];

  const { data: profit } = useRequest(querySimulationProfit, {
    defaultParams: [
      {
        project_id: projectId,
        s_time: dayjs().subtract(1, 'day').format('YYYY-MM-DD'),
        e_time: dayjs().format('YYYY-MM-DD'),
      },
    ],
    formatResult(data) {
      if (!data?.info) return '-';

      return Object.values(data.info).reduce(
        (total, currentValue) => total + currentValue,
        0,
      );
    },
  });
  const { data } = useRequest(queryMandateChildList, {
    defaultParams: [
      {
        projectId,
        mandateClass: 2,
      },
    ],
  });
  return (
    <Panel
      title="成本节约类"
      style={{ marginBottom: 20 }}
      btns={
        <Button
          type="primary"
          onClick={() => history.push(`/smart/simulate/${projectId}`)}
        >
          模拟评估
        </Button>
      }
    >
      {data?.length > 0 && (
        <>
          <h3 className={styles.title}>任务总结</h3>
          <div className={styles.desc}>
            通过能耗/药耗数据模拟仿真预计未来一日可节省
            <span>{profit || '-'}</span>元
          </div>
          <Table columns={columns} dataSource={data} />
        </>
      )}
      {!data?.length && (
        <>
          <h3 className={styles.title}>任务总结</h3>
          <div className={styles.desc}>暂无可降低成本，继续保持哦~</div>
        </>
      )}
    </Panel>
  );
};

export default OptimizationTasks;
